@@ -5,15 +5,14 @@
 
     A port of Ruby on Rails' inflector to Python.
 
-    :copyright: (c) 2012 by Janne Vanhala
-    :copyright: (c) 2005-2012 by David Heinemeier Hansson
+    :copyright: (c) 2013 by Janne Vanhala
 
     :license: MIT, see LICENSE for more details.
 """
 import re
 import unicodedata
 
-__version__ = '0.1.2'
+__version__ = '0.2.0'
 
 PLURALS = [
     (r"(?i)(quiz)$", r'\1zes'),
@@ -366,12 +365,13 @@ def transliterate(string):
     Examples::
 
         >>> transliterate(u'älämölö')
-        'alamolo'
+        u'alamolo'
         >>> transliterate(u'Ærøskøbing')
-        'rskbing'
+        u'rskbing'
 
     """
-    return unicodedata.normalize('NFKD', string).encode('ascii', 'ignore')
+    normalized = unicodedata.normalize('NFKD', string)
+    return normalized.encode('ascii', 'ignore').decode('ascii')
 
 
 def underscore(word):
